pubDate

# XMLRésuméLibrary: User Guide

pub | Element Reference | publisher

## Name

pubDate — The date a work was published

Deprecated

## Synopsis

### Content Model

    (month?,year)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

### Important

This element is deprecated as of XML Résumé Library version 1.4.0. It should not be used.

`date` elements should be used instead of `pubDate` elements.

The `pubDate` element indicates when a literary, scholarly, or other work was published. It must contain a `year`, and may contain a `month`.

### Parents

`pubDate` may be contained in these elements: `pub`

## See Also

`date`.

## Examples

    <pub>
      <bookTitle>How to Drink Water for Fun and Profit</bookTitle>
      <pubdate>
        <year>1996</year>
      </pubdate>
    </pub>

    <pub>
      <artTitle>Modern Neo-Classical Baroque Music</bookTitle>
      <bookTitle>Journal of Classical Music</bookTitle>
      <pubdate>
        <month>July</month>
        <year>1931</year>
      </pubdate>
    </pub>

pub | Element Reference | publisher